IsarCollectionAccessor class

Helper interface so users can supply Isar specific operations

Constructors

IsarCollectionAccessor({required Future<List<Map<String, dynamic>>> getAllRecords(), required Future<void> putRecord(Map<String, dynamic> data), required Future<void> deleteRecord(dynamic data)})

Properties

deleteRecord Future<void> Function(dynamic data)
final
getAllRecords Future<List<Map<String, dynamic>>> Function()
final
hashCode int
The hash code for this object.
no setterinherited
putRecord Future<void> Function(Map<String, dynamic> data)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited