SharedPreferencesAdapter class

Implemented types

Constructors

SharedPreferencesAdapter(SharedPreferences prefs)

Properties

hashCode int
The hash code for this object.
no setterinherited
prefs → SharedPreferences
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteRecord(String tableName, dynamic id) Future<void>
override
executeRawQuery(String query) Future<List<Map<String, dynamic>>>
override
exportData() Future<void>
override
getRecords(String tableName) Future<List<Map<String, dynamic>>>
override
getTables() Future<List<String>>
override
importData(dynamic data) Future<void>
override
insertRecord(String tableName, Map<String, dynamic> data) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRecord(String tableName, dynamic id, Map<String, dynamic> data) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited