DatabaseAdapter class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteRecord(
String tableName, dynamic id) → Future< void> -
executeRawQuery(
String query) → Future< List< Map< >String, dynamic> > -
exportData(
) → Future< void> -
getRecords(
String tableName) → Future< List< Map< >String, dynamic> > -
getTables(
) → Future< List< String> > -
importData(
dynamic data) → Future< void> -
insertRecord(
String tableName, Map< String, dynamic> data) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRecord(
String tableName, dynamic id, Map< String, dynamic> data) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited