BackupService class
Constructors
- BackupService(DatabaseAdapter adapter)
Properties
- adapter → DatabaseAdapter
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createBackup(
String databaseIdentifier) → Future< String> -
listBackups(
) → Future< List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restoreBackup(
String backupPath) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited