collections property
Map of collection names to a function that retrieves all records as Map Or just an accessor to the schema if they want to pass it manually. For MVP, we need a way to read/write generically. Since Isar relies on generated code, the user provides generic callbacks.
Implementation
final Map<String, IsarCollectionAccessor> collections;